@@ -31,6 +31,7 @@ from .sqlexecute import SQLExecute
 from .sqlparse import SQLMapping
 from .kafkawrapper import KafkaWrapper
 from .comparewrapper import CompareWrapper
+from .hdfswrapper import HDFSWrapper
 from .sqlcliexception import SQLCliException
 from .sqlclisga import SQLCliGlobalSharedMemory
 from .sqlinternal import Create_file
@@ -103,6 +104,7 @@ class SQLCli(object):
         self.SQLOptions = SQLOptions()                   # 程序运行中各种参数
         self.KafkaHandler = KafkaWrapper()               # Kafka消息管理器
         self.CompareHandler = CompareWrapper()           # 参照结果文件比对
+        self.HdfsHandler = HDFSWrapper()                 # HDFS文件操作
         self.JobHandler = JOBManager()                   # 并发任务管理器
         self.TransactionHandler = TransactionManager()   # 事务管理器
         self.SpoolFileHandler = None                     # 当前Spool文件句柄
@@ -1064,6 +1066,13 @@ class SQLCli(object):
             yield title, result, headers, columntypes, status
             return
 
+        # 处理HDFS数据
+        matchObj = re.match(r"(\s+)?hdfs(.*)$", arg, re.IGNORECASE | re.DOTALL)
+        if matchObj:
+            (title, result, headers, columntypes, status) = self.HdfsHandler.Process_SQLCommand(arg)
+            yield title, result, headers, columntypes, status
+            return
+
         # 创建数据文件, 根据末尾的rows来决定创建的行数
         # 此时，SQL语句中的回车换行符没有意义
         matchObj = re.match(r"create\s+(.*?)\s+file\s+(.*?)\((.*)\)(\s+)?rows\s+(\d+)(\s+)?$",
@@ -1313,9 +1322,6 @@ class SQLCli(object):
         # 程序运行的结果
         m_runCli_Result = True
 
-        # 设置主程序的标题，随后开始运行程序
-        setproctitle.setproctitle('SQLCli MAIN ' + " Script:" + str(self.sqlscript))
-
         # 加载程序的配置文件
         self.AppOptions = configparser.ConfigParser()
         m_conf_filename = os.path.join(os.path.dirname(__file__), "conf", "sqlcli.ini")
@@ -1432,6 +1438,10 @@ class SQLCli(object):
             if "SQLCLI_DEBUG" not in os.environ:
                 self.SQLOptions.set("SILENT", "OFF")
 
+        # 设置主程序的标题，随后开始运行程序
+        m_Cli_ProcessTitleBak = setproctitle.getproctitle()
+        setproctitle.setproctitle('SQLCli MAIN ' + " Script:" + str(self.sqlscript))
+
         # 开始依次处理SQL语句
         try:
             # 如果用户指定了用户名，口令，尝试直接进行数据库连接
@@ -1448,8 +1458,6 @@ class SQLCli(object):
                     m_runCli_Result = False
                     raise EOFError
                 self.DoSQL('exit')
-                self.echo("Disconnected.")
-                return m_runCli_Result
             else:
                 # 循环从控制台读取命令
                 while True:
@@ -1464,7 +1472,12 @@ class SQLCli(object):
             for transaction_name in m_TransactionNames:
                 self.TransactionHandler.TransactionFail(transaction_name)
             # SQLCliException只有在被设置了WHENEVER_SQLERROR为EXIT的时候，才会被捕获到
-            self.echo("Disconnected.")
+
+        # 退出进程
+        self.echo("Disconnected.")
+
+        # 还原进程标题
+        setproctitle.setproctitle(m_Cli_ProcessTitleBak)
 
         # 返回运行结果, True 运行成功。 False运行失败
         return m_runCli_Result
@@ -1483,7 +1496,12 @@ class SQLCli(object):
             click.echo(s, file=self.logfile)
         if self.logger is not None:
             self.logger.info(s)
-        click.secho(s, **kwargs, file=self.Console)
+        try:
+            click.secho(s, **kwargs, file=self.Console)
+        except UnicodeEncodeError as ue:
+            # Unicode Error, This is console issue, Skip
+            if "SQLCLI_DEBUG" in os.environ:
+                print("Console output error:: " + repr(ue))
         if self.SpoolFileHandler is not None:
             click.echo(s, file=self.SpoolFileHandler)
 
